==> haskell-hxt-regex-xmlschema-9.2.0.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-regex-xmlschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-regex-xmlschema
version: 9.2.0.3
id: hxt-regex-xmlschema-9.2.0.3-DrZkVaqhcka8zPjgBegtWX
key: hxt-regex-xmlschema-9.2.0.3-DrZkVaqhcka8zPjgBegtWX
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: stable
homepage: http://www.haskell.org/haskellwiki/Regular_expressions_for_XML_Schema
synopsis: A regular expression library for W3C XML Schema regular expressions
description:
    This library supports full W3C XML Schema regular expressions
    inclusive all Unicode character sets and blocks.
    The complete grammar can be found under <http://www.w3.org/TR/xmlschema11-2/#regexs>.
    It is implemented by the technique of derivations of regular expressions.
    .
    The W3C syntax is extended to support not only union of regular sets,
    but also intersection, set difference, exor.
    Matching of subexpressions is also supported.
    .
    The library can be used for constricting lightweight scanners and tokenizers.
    It is a standalone library, no external regex libraries are used.
    .
    Extensions in 9.2: The library does nor only support String'\''s, but also
    ByteString'\''s and Text in strict and lazy variants
category: Text
author: Uwe Schmidt
exposed: True
exposed-modules:
    Text.Regex.Glob.String Text.Regex.Glob.Generic
    Text.Regex.Glob.Generic.RegexParser Text.Regex.XMLSchema.String
    Text.Regex.XMLSchema.Generic Text.Regex.XMLSchema.Generic.Matching
    Text.Regex.XMLSchema.Generic.RegexParser
    Text.Regex.XMLSchema.Generic.Regex
    Text.Regex.XMLSchema.Generic.StringLike
abi: 2f0b967e5c03088a8d18591d1026e0f4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hxt-regex-xmlschema-9.2.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hxt-regex-xmlschema-9.2.0.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/hxt-regex-xmlschema-9.2.0.3
hs-libraries: HShxt-regex-xmlschema-9.2.0.3-DrZkVaqhcka8zPjgBegtWX
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    hxt-charproperties-9.2.0.1-L1rhanzXQ304SfBOSkeXkX
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-hxt-regex-xmlschema/html/hxt-regex-xmlschema.haddock
haddock-html: /usr/share/doc/haskell-hxt-regex-xmlschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-regex-xmlschema-9.2.0.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hxt-regex-xmlschema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt-regex-xmlschema
version: 9.2.0.3
id: hxt-regex-xmlschema-9.2.0.3-4X3gseSrjYwJtPzBLX5050
key: hxt-regex-xmlschema-9.2.0.3-4X3gseSrjYwJtPzBLX5050
license: MIT
copyright: Copyright (c) 2010- Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: stable
homepage: http://www.haskell.org/haskellwiki/Regular_expressions_for_XML_Schema
synopsis: A regular expression library for W3C XML Schema regular expressions
description:
    This library supports full W3C XML Schema regular expressions
    inclusive all Unicode character sets and blocks.
    The complete grammar can be found under <http://www.w3.org/TR/xmlschema11-2/#regexs>.
    It is implemented by the technique of derivations of regular expressions.
    .
    The W3C syntax is extended to support not only union of regular sets,
    but also intersection, set difference, exor.
    Matching of subexpressions is also supported.
    .
    The library can be used for constricting lightweight scanners and tokenizers.
    It is a standalone library, no external regex libraries are used.
    .
    Extensions in 9.2: The library does nor only support String'\''s, but also
    ByteString'\''s and Text in strict and lazy variants
category: Text
author: Uwe Schmidt
exposed: True
exposed-modules:
    Text.Regex.Glob.String Text.Regex.Glob.Generic
    Text.Regex.Glob.Generic.RegexParser Text.Regex.XMLSchema.String
    Text.Regex.XMLSchema.Generic Text.Regex.XMLSchema.Generic.Matching
    Text.Regex.XMLSchema.Generic.RegexParser
    Text.Regex.XMLSchema.Generic.Regex
    Text.Regex.XMLSchema.Generic.StringLike
abi: e3198717409561bcfa7ab4f2c5b7f4fa
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hxt-regex-xmlschema-9.2.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/hxt-regex-xmlschema-9.2.0.3
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/hxt-regex-xmlschema-9.2.0.3
hs-libraries: HShxt-regex-xmlschema-9.2.0.3-4X3gseSrjYwJtPzBLX5050
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    hxt-charproperties-9.2.0.1-L1rhanzXQ304SfBOSkeXkX
    parsec-3.1.11-LsiSww7OPVN4zZBDwUQHXr
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-hxt-regex-xmlschema/html/hxt-regex-xmlschema.haddock
haddock-html: /usr/share/doc/haskell-hxt-regex-xmlschema/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
